<?php
// $Id: moon_phases.admin.inc,v 1.2.2.2 2010/12/11 17:36:05 tomcamp Exp $

/**
 * @file
 * 	Administrative forms and functions for the moon_phases module
 * @author Tom Camp <tom@campsitemedia.com>
 * @since 07/09/2010
 * @version 0.5
 */

/**
 * The form to set the Zip Code for your form /admin/settings/moon
 * @param array $form_state
 * @return array $form
 */
function moon_phases_admin_form( &$form_state ) {

  $lat = variable_get( 'moon_lat', null );
  $lon = variable_get( 'moon_lon', null );

  if ( $lat && $lon ) {
    $form[ 'latlon' ] = array(
      '#value' => t( 'Latitude %lat, Longitude %lon', array( '%lat' => $lat, '%lon' => $lon ) )
    );
  }

  $form[ 'moon_zip' ] = array(
    '#type' => 'textfield',
    '#title' => t( 'Enter Zip Code' ),
    '#default_value' => variable_get( 'moon_zip', null ),
    '#size' => 11,
    '#maxlength' => 10,
    '#description' => t( 'Format: 10001 or 10001-1234 or 10001 1234' ),
  );

  $form[ 'submit' ] = array(
    '#type' => 'submit',
    '#value' => t( 'Submit' )
  );

  return $form;

} // function moon_phases_admin_form()


/**
 * _validation function for moon_phases_admin_form
 *  Check length of zip code to make sure it is either 5 or 9 characters long
 *  Check to make sure that it only contains numerics, - or a space
 * @param array $form
 * @param array $form_state
 */
function moon_phases_admin_form_validate( $form, &$form_state ) {

  if ( strlen( $form_state[ 'values' ][ 'moon_zip' ] ) < 5 || strlen( $form_state[ 'values' ][ 'moon_zip' ] ) > 10 || ( strlen( $form_state[ 'values' ][ 'moon_zip' ] ) < 10 && strlen( $form_state[ 'values' ][ 'moon_zip' ] ) > 5 )  ) {
    form_set_error( 'moon_zip', t( 'The zip code you entered is not valid.' ) );
    $valid = false;
  }
  elseif ( is_numeric( $form_state[ 'values' ][ 'moon_zip' ] ) && strlen( $form_state[ 'values' ][ 'moon_zip' ] ) == 5 ) {
    $valid = true;
  }
  elseif ( strlen( $form_state[ 'values' ][ 'moon_zip' ] ) == 10 ) {
    if ( preg_match( '/^[0-9]{5}([- ]?[0-9]{4})?$/', $form_state[ 'values' ][ 'moon_zip' ] ) ) {
      $valid = true;
    }
    else {
      form_set_error( 'moon_zip', t( 'The zip code you entered is not valid.' ) );
      $valid = false;
    }
  }

  if ( $valid ) {
    drupal_set_message( t( 'Zip Code set to %z.', array( '%z' => $form_state[ 'values' ][ 'moon_zip' ] ) ), 'status', false );
    variable_set( 'moon_zip', str_ireplace( ' ', '-', $form_state[ 'values' ][ 'moon_zip' ] ) );
  }

} // function moon_phases_admin_form_validate


/**
 * _submition function for moon_phases_admin_form
 * @param	array $form
 * @param	array $form_state
 */
function moon_phases_admin_form_submit( $form, &$form_state ) {

  moon_phases_admin_get_latlon( $form_state[ 'values' ][ 'moon_zip' ] );

} // function moon_phases_admin_form_submit


/**
 * Get the latitude and longitude for the zip code entered from NOAA
 * @param	 string 	$zip - Zip Code
 * @return boolean 	true
 */
function moon_phases_admin_get_latlon( $zip ) {

  $base_url = 'http://www.weather.gov/forecasts/xml/DWMLgen/wsdl/ndfdXML.wsdl';
  $parameters = array( 'zipCodeList' => str_ireplace( ' ', '-', $zip ) );

  $client = new SoapClient( $base_url );

  try {
    $results = $client->__soapCall( 'LatLonListZipCode', $parameters );
    $data = get_object_vars( simplexml_load_string( $results ) );
    $latLon = explode( ',', $data[ 'latLonList' ] );

    variable_set( 'moon_lat', $latLon[ 0 ] );
    variable_set( 'moon_lon', $latLon[ 1 ] );
    drupal_set_message( t( 'Latitude set to %lat and longitude set to %lon.', array( '%lat' => $latLon[ 0 ], '%lon' => $latLon[ 1 ] ) ), 'status', false );
  }
  catch( Exception $e ) {
    drupal_set_message( t( 'Error retrieving data. Exception caught: %e', array( '%e' => $e->getMessage() ) ) );
  }

  return true;

} // function moon_phases_admin_get_latlon
